# lightcurve_fitting

This package contains tools to fit analytical models to multiband light curves of astronomical transients.

For a quick guide to get started, see the included Jupyter notebook [lightcurve_fitting.ipynb](lightcurve_fitting.ipynb).

The documentation is a bit sparse right now, but feel free to contact the author for help.

If you use this code in a publication, please **cite the original papers** whose models you used, as well as my Zenodo repository. [![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.2639463.svg)](https://doi.org/10.5281/zenodo.2639463)
